
def api_manager_usage():
    usage = '''
        qetl_manage_user [-h] -p PARENT -c CHILD [-t] [-u] [-n] [-r] [-y] [-e]

Examples of usage:
  1) Create New User    - qetl_manage_user -p /usr/local/qetl -c qualys_user01 -t
  2) Report User        - qetl_manage_user -p /usr/local/qetl -c qualys_user01 -r
  3) Test User          - qetl_manage_user -p /usr/local/qetl -c qualys_user01 -t
  4) Credentials update - qetl_manage_user -p /usr/local/qetl -c qualys_user01 -u
  4) Execute ETL Job    - qetl_manage_user -p /usr/local/qetl -c qualys_user01 -e etl_kb_main

Description: Manage your qetl users.
    Key Points:
      - There is one directory for each qualys user.
      - The parent directory is the qetl root directory for your users.  Ex. /usr/local/qetl 
      - The child directory is your qetl user that you want to use.  
        ex. qualys_user_01 located under 
      - This command is the user interface to the ETL system.
    
    Example Uses of qetl_manage_user: 
        1) [-n] Create New User, generating application directories.
        2) [-t] Test New User
        3) [-y] Update Credentials (username, password, api_fqdn_server) 
        4) [-r] Report of Application Directory and Files 
        5) [-e] Execute ETL Job.  Ex. -e etl_kb  
                See bin directory in report [-r] for options.

        Execute qetl_manage_user -h for details

    Example User Directory Structure: 
        User Directory /usr/local/qetl/qualys_user_01/qetl_home
           1) /usr/local/qetl: Parent dir for all your users
           2) /usr/local/qetl/qualys_user_01: Child dir for
              single qualys user
           3) /usr/local/qetl/qualys_user_01/qetl_home: 
              Application cred,config,data,log directories
    
    In the example above, qetl_home directories are generated

    The qetl_home directory is where the user programs for a single
    qualys userid live and they are generated through this command.
    For example: Directory /usr/local/qetl/qualys_user_01 contains: 
         1) qetl_home/config
         2) qetl_home/data
         3) qetl_home/log
         4) qetl_home/cred
                 
    Examples:
       1) ETL the KnowledgeBase data files:
          /usr/local/qetl/qualys_user_01/qetl_home/data/kb.*
       2) ETL the Host List data files:
          /usr/local/qetl/qualys_user_01/qetl_home/data/host_list.*
    
    See github documentation for more details
    usage: qetl_manage_user [-h] -p PARENT -c CHILD [-t] [-u] [-n] [-r] [-y] [-e]
    '''
    return usage





from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
from qualys_etl.etld_lib import etld_lib_credentials as etld_lib_credentials
from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
from qualys_etl.etld_lib import etld_lib_distribution as api_dist


def kb_dist():
    try:
        file_paths = (
            etld_lib_config.kb_sqlite_file,
            etld_lib_config.kb_cve_qid_file,
            etld_lib_config.kb_csv_file,
            etld_lib_config.kb_json_file,
            etld_lib_config.kb_xml_file
        )
        api_dist.copy_results_to_external_target(file_paths, etld_lib_config.kb_export_dir)
    except Exception as e:
        etld_lib_functions.logger.error(f"Exception: {e}")
        exit(1)


def start_msg_kb_dist():
    etld_lib_functions.logger.info(f"start")


def end_msg_kb_dist():
    etld_lib_functions.logger.info(f"end")


def main():
    start_msg_kb_dist()
    kb_dist()
    end_msg_kb_dist()


if __name__ == "__main__":
    etld_lib_functions.main(my_logger_prog_name="kb_distribution")
    etld_lib_config.main()
    etld_lib_credentials.main()
    main()



import shutil
import os
from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions


def copy_results_to_external_target(source_list=None, target=None):

    if target == 'default':
        etld_lib_functions.logger.info(f"No export_dir set: {target}")
        pass
    elif os.path.isdir(target):
        try:
            for file_path in source_list:
                if os.path.exists(file_path):
                    shutil.copy2(str(file_path), str(target), follow_symlinks=True)
                    etld_lib_functions.logger.info(f"{str(file_path)} distributed to {str(target)}")

                else:
                    etld_lib_functions.logger.warning(f"file doesn't exists:{str(file_path)} "
                                            f"cannot distribute to {str(target)}")
                    pass
        except Exception as e:
            etld_lib_functions.logger.error(f"Exception: {e}")
            etld_lib_functions.logger.error(f"Error distributing files.  ")
            etld_lib_functions.logger.error(f"etld_lib_config_settings.yaml [named]_export_dir "
                                            f"directory accessibility issue: {target}")
            exit(1)
    else:
        etld_lib_functions.logger.error(f"etld_lib_config_settings.yaml [named]_export_dir directory does not exist: {target}")
        exit(1)
